Nodes — MARV Robotics 21.10.0 documentation

# Nodes

## Bag metadata

marv_robotics.bag.bagmeta()

  Extract meta information from bag file.

  In case of multiple connections for one topic, they are assumed to be all of the same message type and either all be latching or none.

  A topic’s message type and latching mode, and a message type’s md5sum are assumed not to change across split bags.

## ROS bag messages

marv_robotics.bag.raw_messages()

  Stream messages from a set of bag files.

marv_robotics.bag.make_deserialize()

  Create appropriate deserialize function for rosbag1 and 2.

marv_robotics.bag.make_get_timestamp()

  Make utitliy to get message header timestamp in nanoseconds.

  Falling back to bag message timestamp if header stamp is zero or unavailable.

  Parameters

    - log – logger instance

    - stream – Obsolete, previously needed argument

  Returns

    Function retrieving timestamp from message.

## Images

marv_robotics.cam.images()

  Extract max_frames equidistantly spread images from each image stream.

  Parameters

    - stream – sensor_msgs/msg/Image or sensor_msgs/msg/CompressedImage stream

    - image_width (int) – Scale to image_width, keeping aspect ratio.

    - max_frames (int) – Maximum number of frames to extract.

    - convert_32FC1_scale (float) – Scale factor for FC image values.

    - convert_32FC1_offset (float) – Offset for FC image values.

  Yields

    Images section.

## Video

marv_robotics.cam.ffmpeg()

  Create video for each image topic with ffmpeg.

## Fulltext

marv_robotics.fulltext.fulltext()

  Extract all text from bag file and store for fulltext search.

## GNSS

marv_robotics.gnss.positions()

marv_robotics.gnss.imus()

marv_robotics.gnss.navsatorients()

marv_robotics.gnss.orientations()

marv_robotics.gnss.gnss_plots()

## Trajectory

marv_robotics.trajectory.navsatfix()

marv_robotics.trajectory.trajectory()

## Widget nodes

Widgets are used by sections or are rendered in the special summary sections when configured in the detail_summary_widgets config key.

marv_robotics.detail.bagmeta_table()

  Table widget listing metadata for each bag of dataset.

  Useful for detail_summary_widgets.

marv_robotics.detail.summary_keyval()

  Keyval widget summarizing bag metadata.

  Useful for detail_summary_widgets.

marv_robotics.detail.galleries()

  Galleries for all images streams.

  Used by marv_robotics.detail.images_section.

## Section nodes

marv_robotics.detail.images_section()

  Section with galleries of images for each images stream.

marv_robotics.detail.connections_section()

  Section displaying information about ROS connections.

marv_robotics.detail.trajectory_section()

  Section displaying trajectory on a map.

  Parameters

    - title (str) – Detail section title.

    - geojson – Stream with one GeoJson message.

    - minzoom (int) – Minimum zoom level.

    - maxzoom (int) – Maximum zoom level.

    - tile_server_protocol (str) – Set to `https:` if you host marv behind http and prefer the tile requests to be secured.

  Yields

    Trajectory section.

  Raises

    Abort – If stream is empty.

marv_robotics.detail.video_section()

  Section displaying one video player per image stream.

marv_robotics.detail.gnss_section()

  Section displaying GNSS plots.